@@ -35,7 +35,7 @@ if __name__ == '__main__':
     # add user paths to sys.path
     if args.syspath:
         for path in args.syspath:
-            print('append path %s to sys.path\n' % path)
+            print('append path %s to sys.path' % path)
             sys.path.append(path)
 
     from pyqode.core import backend
